@@ -9,18 +9,25 @@ public abstract class ProfileParametersBase<T extends ProfileBase> extends VdcAc
 
     private static final long serialVersionUID = 1303387921254823324L;
 
-    public ProfileParametersBase() {
+    private boolean addPermissions;
 
+    public ProfileParametersBase(boolean addPermissions) {
+        this.addPermissions = addPermissions;
     }
 
-    public ProfileParametersBase(T profile, Guid profileId) {
+    public ProfileParametersBase(T profile, boolean addPermissions) {
+        this.profile = profile;
+        this.addPermissions = addPermissions;
+    }
+
+    public ProfileParametersBase(T profile) {
         this.profile = profile;
-        this.profileId = profileId;
     }
 
     @Valid
     private T profile;
-    private Guid profileId;
+
+    public ProfileParametersBase() {}
 
     public T getProfile() {
         return profile;
@@ -31,11 +38,19 @@ public abstract class ProfileParametersBase<T extends ProfileBase> extends VdcAc
     }
 
     public Guid getProfileId() {
-        return profileId;
+        return profile.getId();
     }
 
     public void setProfileId(Guid profileId) {
-        this.profileId = profileId;
+        this.profile.setId(profileId);
+    }
+
+    public boolean isAddPermissions() {
+        return addPermissions;
+    }
+
+    public void setAddPermissions(boolean addPermissions) {
+        this.addPermissions = addPermissions;
     }
 
 }
